// Copyright 2022 ZORALab Enterprise (hello@zoralab.com)
// Copyright 2022 "Holloway" Chew, Kean Ho (hollowaykeanho@gmail.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package thelper

// Scenario is a structure holding the standard simulation scenario data.
//
// It is aligned to the current table-driven, simulation test approach educated
// by many early Go adopter.
//
// It is designed to cater simulation test approach using switches to toggle
// test environment preparations. The idea is that the test suite has a
// generator/factory-like functions sets that simulate a test environments
// for testing.
//
// Upon tested, the test suite uses its own assertion to determine the test
// results. Scenario relies heavily on the following standard test processes:
//   1. generate all the scenarios in the list (table driven approach).
//   2. loop through each scenarios:
//     2.1. check the `TestType` is meant for the test script (algorithm)
//          2.1.1. skip the test case if not compatible using `continue`
//     2.2. prepare simulation environments
//          2.2.1. prepare happy path parameters
//          2.2.2. alters the parameters accordingly based on Switches.
//          2.2.3. generates BOTH the test inputs and the expected output.
//     2.3. run the test
//          2.3.1. execute the test based on the generated test inputs.
//          2.3.2. capture the test outputs.
//     2.4. assert the result using the generated expected output and test
//          output.
//     2.5. log every details for easier assertion statement.
//   3. repeat step 1 for another test script (algorithm).
//
// To configure the simulation environment, the test suite uses the
// map[string]bool Switches field. It allows the tester to dynamically
// configure the simulation preparation functions, case by case basis.
type Scenario struct {
	Switches    map[string]bool
	TestType    string
	Description string
	UID         int
}
